@@ -10,10 +10,12 @@ from cloudmersive_convert_api_client.api.convert_image_api import ConvertImageAp
 from cloudmersive_convert_api_client.api.convert_template_api import ConvertTemplateApi
 from cloudmersive_convert_api_client.api.convert_web_api import ConvertWebApi
 from cloudmersive_convert_api_client.api.edit_document_api import EditDocumentApi
+from cloudmersive_convert_api_client.api.edit_html_api import EditHtmlApi
 from cloudmersive_convert_api_client.api.edit_pdf_api import EditPdfApi
 from cloudmersive_convert_api_client.api.edit_text_api import EditTextApi
 from cloudmersive_convert_api_client.api.merge_document_api import MergeDocumentApi
 from cloudmersive_convert_api_client.api.split_document_api import SplitDocumentApi
+from cloudmersive_convert_api_client.api.transform_document_api import TransformDocumentApi
 from cloudmersive_convert_api_client.api.validate_document_api import ValidateDocumentApi
 from cloudmersive_convert_api_client.api.viewer_tools_api import ViewerToolsApi
 from cloudmersive_convert_api_client.api.zip_archive_api import ZipArchiveApi
